@@ -14,7 +14,7 @@ require(lars)
     mf <- eval(mf, parent.frame())
     mt <- attr(mf, "terms")
     y <- model.response(mf, "numeric")
-    X <- delete.intercept(model.matrix(mt, mf))
+    X <- pls:::delete.intercept(model.matrix(mt, mf))
 
 
 mod_lasso <- lars(X,y)
